# Copyright 2017 by Matthias Goerner, enischte@gmail.com.
#
# This code is released under the `GNU General Public License, version 2
# <http://www.gnu.org/licenses/gpl-2.0.txt>`_ or (at your option) any
# later version as published by the Free Software Foundation.

from bianchiOrbifold import *

from sage.all import Integer

import sys

usage = """Usage: sage -python generateBianchiOrbifold D range_a range_d

Creates the orbifold associated to the Bianchi group PSL(2, O) where O is the
ring of integers in Q(sqrt(-D)), saving the result into a regina file, see
OrbifoldData for more details.

D has to be square-free. range_a and range_d determine how many matrices are
used when trying to find a candidate Dirichlet domain.

For example, to generate the Bianchi orbifold for Q(sqrt(-1)), run

    sage -python generateBianchiOrbifold.py  1  2  2

More example:
    sage -python generateBianchiOrbifold.py  2  2  2
    sage -python generateBianchiOrbifold.py  3  2  2
    sage -python generateBianchiOrbifold.py  5  7  7
    sage -python generateBianchiOrbifold.py  6  9  9
    sage -python generateBianchiOrbifold.py  7  2  2
    sage -python generateBianchiOrbifold.py 11  2  2
    sage -python generateBianchiOrbifold.py 15  7  7
    sage -python generateBianchiOrbifold.py 19  2  2
    sage -python generateBianchiOrbifold.py 23  4  6
    sage -python generateBianchiOrbifold.py 31  6  6
    sage -python generateBianchiOrbifold.py 39 10 10
    sage -python generateBianchiOrbifold.py 47  9  9
    sage -python generateBianchiOrbifold.py 71 17 17
 
"""

if __name__ == '__main__':
    if len(sys.argv) != 4:
        print usage
        sys.exit(1)
    
    D = Integer(sys.argv[1])
    range_a = Integer(sys.argv[2])
    range_b = Integer(sys.argv[3])

    B = generateBianchiOrbifold(D, range_a, range_b)

    name = filenameForBianchiOrbifold(D)
    compressed = False
    B.save(name, compressed)
    
    print "Saved as: ", name
    
