# Copyright 2018 by Matthias Goerner, enischte@gmail.com.
#
# This code is released under the `GNU General Public License, version 2
# <http://www.gnu.org/licenses/gpl-2.0.txt>`_ or (at your option) any
# later version as published by the Free Software Foundation.

from bianchiOrbifold import *
from principalCongruenceManifold import *

from trigUtils.formatting import formatReginaStatistics

from sage.all import Integer, QQ

import sys

usage = """Usage: sage -python generateGamma1Manifold.py D a b [c d] [e f] ...

Creates the manifold obtained as quotient by the congruence group
           (PSL(2, O) -> SL(2, O/I) / {+1/-1})^-1 (P)
where O is the ring of integers of Q(sqrt(-D)), P are the unit upper triangular
matrices in SL(2, O/I) / {+1/-1} and I the ideal generated by
a + b * sqrt(-D) and (if supplied) c + d * sqrt(-D), e + f * sqrt(-D), ...
D is assumed to be square-free.

The complement of the congruence link 8^4_2 (of level 2 + 2i) can, for example,
be created with:
    sage -python generateGamma1Manifold.py 1 2 2

If a and b are small such that the principal congruence group has torsion, the
topological manifold underlying the orbifold will be created (as there is
currently no nice way to mark the singular locus of the orbifold).
"""

if __name__ == '__main__':
    
    if len(sys.argv) < 4 or len(sys.argv) % 2 == 1:
        print usage
        sys.exit(1)

    D = Integer(sys.argv[1])
    imagQuadraticFieldUtil = ImagQuadraticFieldUtil(D)

    gens = [
        imagQuadraticFieldUtil.getAlgebraicInteger(QQ(a), QQ(b))
        for a, b in zip(sys.argv[2::2], sys.argv[3::2]) ]

    ideal = Ideal(imagQuadraticFieldUtil, gens)

    g = generatePrincipalCongruenceManifold(ideal, is_gamma1 = True)

    g.triangulation.save(g.baseName + '.rga')
    print "Saved as:", g.baseName + '.rga'

    # Write some additional, helpful information to disk
    open(g.baseName + '.stats','w').write(
        formatReginaStatistics(g.triangulation))
