# Copyright 2017 by Matthias Goerner, enischte@gmail.com.
#
# This code is released under the `GNU General Public License, version 2
# <http://www.gnu.org/licenses/gpl-2.0.txt>`_ or (at your option) any
# later version as published by the Free Software Foundation.

import snappy
import regina

import sys, os

from trigUtils import *

usage = """Usage: python reginaToSnapPy.py FILE.rga
   or: sage -python reginaToSnapPy.py FILE.rga

Converts a regina triangulation to a SnapPy Manifold and saves it to disk.
"""

if __name__ == '__main__':
    if len(sys.argv) != 2:
        print usage
        sys.exit(1)

    name, ext = os.path.splitext(sys.argv[1])

    with TimingMeasurement("total"):

        with TimingMeasurement("opening regina triangulation"):
            T = regina.open(sys.argv[1])

        with TimingMeasurement("converting to SnapPy"):
            M = snappy.Triangulation(T)

        outfile = name + '.tri'

        with TimingMeasurement("saving SnapPy triangulation"):
            M.save(outfile)

    print "Saved as:", outfile
    print "Number of tetrahedra:", M.num_tetrahedra()

