import time

__all__ = ['TimingMeasurement']

class TimingMeasurement:
    """
    An object measuring CPU time and printing it out with a user supplied
    message::

    >>> with TimingMeasurement("Long operation"):
    ...    foo()
    
    It can be nested::
    
    >>> with TimingMeasurement("total"):
    ...     with TimingMeasurement("Operation 1"):
    ...         foo()
    ...     with TimingMeasurement("Operation 2"):
    ...         bar()

    """

    def __init__(self, msg):
        self.msg = msg
    
    def __enter__(self):
        self.start = time.clock()
        return self

    def __exit__(self, type, value, traceback):
        print 'Time for %s: %s' % (
            self.msg, formatTime(time.clock() - self.start))

def formatHumanReadableTime(t):
    if t < 60:
        return '%.3f s' % t

    s = int(t)
    if s < 3600:
        return '%d min %d s' % (
            s / 60, s % 60)
    if s < 86400:
        return '%d h %d min' % (
            s / 3600, (s / 60) % 60)
    if s < 7 * 86400:
        return '%d d %d h %d min' % (
            s / 86400, (s / 3600) % 24, (s / 60) % 60)
    return '%d d %d h' % (
        s / 86400, (s / 3600) % 60)

def formatTime(t):
    return '%s      [ %.3f s ]' % (formatHumanReadableTime(t), t)

